@@ -11,6 +11,7 @@ from ama_xiv_combat_sim.simulator.timeline_builders.rotation_builder import (
     RotationBuilder,
 )
 
+
 class TestJobsUnified705(TestClass):
     def __init__(self):
         super().__init__()
@@ -188,7 +189,6 @@ class TestJobsUnified705(TestClass):
                 SkillModifier(with_condition="Divine Might, Requiescat"),
                 12752,
             ),
-            ("Requiescat", SkillModifier(), 8167),
             ("Holy Circle", SkillModifier(), 2548),
             ("Holy Circle", SkillModifier(with_condition="Divine Might"), 5100),
             ("Holy Circle", SkillModifier(with_condition="Requiescat"), 7651),
@@ -235,7 +235,7 @@ class TestJobsUnified705(TestClass):
         rb = RotationBuilder(
             stats, self.__skill_library, enable_autos=False, ignore_trailing_dots=True
         )
-        rb.add_next("Requiescat")
+        rb.add_next("Imperator")
         rb.add_next("Confiteor")
         rb.add_next("Confiteor")
         rb.add_next("Imperator")
@@ -248,9 +248,9 @@ class TestJobsUnified705(TestClass):
 
         confiteor_damage_big = 25528
         confiteor_damage_small = 12748
-        expected = (
-            ("Requiescat", 8157),
+        expected = (            
             ("Confiteor", confiteor_damage_big),
+            ("Imperator", 14794),
             ("Confiteor", confiteor_damage_big),
             ("Imperator", 14802),
             ("Confiteor", confiteor_damage_big),
@@ -594,12 +594,26 @@ class TestJobsUnified705(TestClass):
             skill_modifier=SkillModifier(with_condition="Remove Buff"),
         )
         rb.add_next("Cascade")
-
+        rb.add_next("Wait 9.00s")
+        rb.add_next("Wait 9.00s")
+        rb.add_next("Wait 9.00s")
+        rb.add_next("Wait 9.00s")
+        rb.add_next("Wait 9.00s")
+        rb.add_next("Wait 9.00s")
+        rb.add_next("Wait 9.00s")
+        rb.add_next("Wait 9.00s")
+        rb.add_next("Wait 9.00s")
+        rb.add_next("Wait 9.00s")
+        rb.add_next("Finishing Move")
+        rb.add_next("Cascade")
+        
         expected = (
             ("Cascade", 10676),
             ("Double Standard Finish", 41262),
             ("Cascade", 11200),
             ("Cascade", 10677),
+            ("Finishing Move", 41249),
+            ("Cascade", 11205),
         )
         test_passed2, err_msg2 = self.__job_class_tester.test_rotation_damage(
             rb, expected
@@ -830,7 +844,10 @@ class TestJobsUnified705(TestClass):
         rb.add_next("Radiant Finale")
         rb.add_next("Sidewinder")
         rb.add_next("Radiant Encore")  # should be 3 coda
-        rb.add_next("Radiant Finale", SkillModifier(with_condition="1 Mage's Coda, 1 Army's Coda"))
+        rb.add_next(
+            "Radiant Finale",
+            SkillModifier(with_condition="1 Mage's Coda, 1 Army's Coda"),
+        )
         rb.add_next("Sidewinder")
         rb.add_next("Radiant Encore")  # should be 2 coda
         rb.add_next("Army's Paeon")
@@ -1341,6 +1358,81 @@ class TestJobsUnified705(TestClass):
 
         return self.__job_class_tester.test_rotation_damage(rb, expected)
 
+    @TestClass.is_a_test
+    def test_nin_tcj_use_all_charges(self):
+        stats = Stats(
+            wd=132,
+            weapon_delay=2.56,
+            main_stat=3360,
+            det_stat=1697,
+            crit_stat=2554,
+            dh_stat=1582,
+            speed_stat=400,
+            job_class="NIN",
+            version=self.__version,
+            level=self.__level,
+        )
+
+        rb = RotationBuilder(
+            stats, self.__skill_library, enable_autos=True, ignore_trailing_dots=True
+        )
+        rb.add(0, "Spinning Edge")        
+        rb.add(2, "Ten Chi Jin")
+        rb.add(3, "Fuma Shuriken")
+        rb.add(5, "Raiton")
+        rb.add(7, "Suiton")
+        rb.add(9.8, "Spinning Edge")
+
+        expected = (
+            ("Spinning Edge", 11899),
+            ("Auto", 3027),            
+            ("Fuma Shuriken", 19833),
+            ("Raiton", 29351),
+            ("Auto", 3027),
+            ("Suiton", 23005),
+            ("Auto", 3027),
+            ("Spinning Edge", 11899),
+            
+        )
+
+        return self.__job_class_tester.test_rotation_damage(rb, expected)
+
+    @TestClass.is_a_test
+    def test_nin_tcj_expire_charges(self):
+        stats = Stats(
+            wd=132,
+            weapon_delay=2.56,
+            main_stat=3360,
+            det_stat=1697,
+            crit_stat=2554,
+            dh_stat=1582,
+            speed_stat=400,
+            job_class="NIN",
+            version=self.__version,
+            level=self.__level,
+        )
+
+        rb = RotationBuilder(
+            stats, self.__skill_library, enable_autos=True, ignore_trailing_dots=True
+        )
+        rb.add(0, "Spinning Edge")        
+        rb.add(2, "Ten Chi Jin")
+        rb.add(3, "Fuma Shuriken")
+        rb.add(5, "Raiton")        
+        rb.add(9.8, "Spinning Edge")
+
+        expected = (
+            ("Spinning Edge", 11899),
+            ("Auto", 3027),            
+            ("Fuma Shuriken", 19833),
+            ("Raiton", 29351),
+            ("Auto", 3027), #only 1 auto, since we wait for TCJ to expire
+            ("Spinning Edge", 11899),
+            
+        )
+
+        return self.__job_class_tester.test_rotation_damage(rb, expected)
+
     @TestClass.is_a_test
     def test_nin_aggregate_rotation(self):
         stats = Stats(
@@ -1693,7 +1785,7 @@ class TestJobsUnified705(TestClass):
         rb.add_next("Umbral Flare")
         rb.add_next("Enkindle Solar Bahamut")
 
-        expected_damage = 703667
+        expected_damage = 694158
         expected_total_time = 47580
         return self.__job_class_tester.test_aggregate_rotation(
             rb, expected_damage, expected_total_time
@@ -1994,6 +2086,68 @@ class TestJobsUnified705(TestClass):
             rb, expected_damage, expected_total_time
         )
 
+    @TestClass.is_a_test
+    def test_vpr_aggregate_rotation_lvl90(self):
+        stats = Stats(
+            wd=132,
+            weapon_delay=2.64,
+            main_stat=3367,
+            det_stat=1736,
+            crit_stat=2587,
+            dh_stat=1494,
+            speed_stat=508,
+            job_class="VPR",
+            version=self.__version,
+            level=90,
+        )
+
+        rb = RotationBuilder(
+            stats,
+            self.__skill_library,
+            enable_autos=True,
+            ignore_trailing_dots=True,
+            snap_dots_to_server_tick_starting_at=0,
+        )
+        skill_seq = (
+            "Vicewinder",
+            "Serpent's Ire",
+            "Grade 8 Tincture",
+            "Hunter's Coil",
+            "Twinfang Bite",
+            "Twinblood Bite",
+            "Swiftskin's Coil",
+            "Twinblood Bite",
+            "Twinfang Bite",
+            "Reawaken",
+            "First Generation",
+            # "First Legacy", lvl > 90 skill
+            "Second Generation",
+            # "Second Legacy",
+            "Third Generation",
+            # "Third Legacy", lvl > 90 skill
+            "Fourth Generation",
+            # "Fourth Legacy", lvl > 90 skill
+            # "Ouroboros", lvl > 90 skill
+            "Vicewinder",
+            "Swiftskin's Coil",
+            "Twinblood Bite",
+            "Twinfang Bite",
+            "Hunter's Coil",
+            "Twinfang Bite",
+            "Twinblood Bite",
+            "Uncoiled Fury",
+            # "Uncoiled Twinfang", lvl > 90 skill
+            # "Uncoiled Twinblood", lvl > 90 skill
+        )
+        for e in skill_seq:
+            rb.add_next(e)
+
+        expected_damage = 469496
+        expected_total_time = 25260
+        return self.__job_class_tester.test_aggregate_rotation(
+            rb, expected_damage, expected_total_time
+        )
+
     @TestClass.is_a_test
     def test_vpr_rotation_damage_instances(self):
         stats = Stats(
